package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.X509Extensions;

public class Request extends ASN1Encodable {
   CertID reqCert;
   X509Extensions singleRequestExtensions;

   public Request(CertID reqCert, X509Extensions singleRequestExtensions) {
      this.reqCert = reqCert;
      this.singleRequestExtensions = singleRequestExtensions;
   }

   public Request(ASN1Sequence seq) {
      this.reqCert = CertID.getInstance(seq.getObjectAt(0));
      if (seq.size() == 2) {
         this.singleRequestExtensions = X509Extensions.getInstance((ASN1TaggedObject)seq.getObjectAt(1), true);
      }

   }

   public static Request getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static Request getInstance(Object obj) {
      if (obj != null && !(obj instanceof Request)) {
         if (obj instanceof ASN1Sequence) {
            return new Request((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (Request)obj;
      }
   }

   public CertID getReqCert() {
      return this.reqCert;
   }

   public X509Extensions getSingleRequestExtensions() {
      return this.singleRequestExtensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.reqCert);
      X509Extensions var3;
      if ((var3 = this.singleRequestExtensions) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(true, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
